# -*- coding: utf-8 -*-

from datetime import date
from openpyxl import load_workbook
from openpyxl.writer.excel import save_virtual_workbook
from openpyxl import Workbook

import os.path
from django.conf import settings
from django.http import HttpResponse


def decode(value):
    if isinstance(value, str):
        return unicode(value, "utf-8")
    return value


def write_excel(ws, data):
    for row_num, row_data in enumerate(data, start=1):
        for col_num, col_data in enumerate(row_data, start=1):
            ws.cell(row=row_num, column=col_num).value = decode(col_data)


def get_template_by_templateid(templateid):
    return os.path.join(settings.STATIC_ROOT, "documents",
                        os.path.basename(templateid))

def get_xlsx_file_name(exportname, simple_filenames):
    """Return the file name for the xlsx file.
    E.g SIB_ESF-Auswertung_2017-11-15.xlsx"""
    program = settings.PROGRAM.upper()
    today = str(date.today())
    template = "{}_{}_Auswertungsvorlage_{}.xlsx"
    if simple_filenames:
        template = "{}_{}_{}.xlsx"
    if exportname == "Teilnahmen":
        exportname = "Rohdaten-Teilnahmen"
    return template.format(program, exportname, today)


def export_xlsx_template(rows, exportname, metadata, templateid=None, simple_filenames=False):
    if templateid == None:
        templateid = "Musterauswertung-leer.xlsx"

    template = get_template_by_templateid(templateid)

    result_filename = get_xlsx_file_name(exportname, simple_filenames)

    wb = load_workbook(filename=template)

    write_excel(wb["Metadaten"], metadata)
    write_excel(wb["Rohdaten"], rows)


    response = HttpResponse(save_virtual_workbook(wb), content_type=
                                        "application/vnd.openxmlformats-"
                                        "officedocument.spreadsheetml.sheet")
    response['Content-Disposition'] = \
        'attachment; filename="%s"' % result_filename

    return response


