import pytest
import reportserver.lib.validators as validators

def test_no_nuts1():
    result = validators.check_nuts1(None, [])
    assert (result is None)

def test_wrong_nuts1():
    with pytest.raises(ValueError):
        validators.check_nuts1("1", [])


def test_nuts1_not_in_allowed():
    with pytest.raises(ValueError):
        validators.check_nuts1("DE1", [])


def test_nuts1_in_allowed():
    result = validators.check_nuts1("DE1", ["DE1"])
    assert (result is None)

def test_nuts1_list():
    result = validators.check_nuts1(["DE1"], ["DE1"])
    assert (result is None)


def test_no_regioncategory():
    result = validators.check_regioncategory(None, [])
    assert (result is None)

def test_wrong_regioncategory():
    with pytest.raises(ValueError):
        validators.check_regioncategory("1", [])


def test_regioncategory_not_in_allowed():
    with pytest.raises(ValueError):
        validators.check_regioncategory("1", [])


def test_regioncategory_in_allowed():
    result = validators.check_regioncategory("1", [1])
    assert (result is None)

def test_no_beneficiary():
    result = validators.check_beneficiary(None, [])
    assert (result is None)

def test_wrong_beneficiary():
    with pytest.raises(ValueError):
        validators.check_beneficiary("1", [])


def test_beneficiary_not_in_allowed():
    with pytest.raises(ValueError):
        validators.check_beneficiary("1", [])


def test_beneficiary_in_allowed():
    result = validators.check_beneficiary("1", ["1"])
    assert (result is None)